@@ -182,9 +182,9 @@ if(!s1 || !s2)
 	}
 	else
 	{
-	int ns1_was_decompressed = 0;
+	int ns1_was_decompressed = HIER_DEPACK_ALLOC;
 	char *ns1 = hier_decompress_flagged(s1, &ns1_was_decompressed);
-	int ns2_was_decompressed = 0;
+	int ns2_was_decompressed = HIER_DEPACK_ALLOC;
 	char *ns2 = hier_decompress_flagged(s2, &ns2_was_decompressed);
 
 	if(*ns1 && *ns2)
@@ -980,7 +980,7 @@ if(nodepnt)
 		else
 		{
 		char *s1, *s2;
-		int s1_was_packed = 0, s2_was_packed = 0;
+		int s1_was_packed = HIER_DEPACK_ALLOC, s2_was_packed = HIER_DEPACK_ALLOC;
 		int root1len=0, root2len=0;
 		int l1, l2;
 
@@ -1191,7 +1191,7 @@ if(nodepnt)
 		else
 		{
 		char *s1, *s2;
-		int s1_was_packed = 0, s2_was_packed = 0;
+		int s1_was_packed = HIER_DEPACK_ALLOC, s2_was_packed = HIER_DEPACK_ALLOC;
 		int root1len=0, root2len=0;
 		int l1, l2;
 
@@ -1610,7 +1610,7 @@ struct symbol *symhi = NULL, *symlo = NULL;
 char hier_delimeter2;
 char *name=NULL;
 char *s1, *s2;
-int s1_was_packed = 0, s2_was_packed = 0;
+int s1_was_packed = HIER_DEPACK_ALLOC, s2_was_packed = HIER_DEPACK_ALLOC;
 int root1len=0, root2len=0;
 int l1, l2;
 
@@ -1773,7 +1773,7 @@ if(!n->extvals)
 	else
 	{
 	char *namex;
-	int was_packed = 0;
+	int was_packed = HIER_DEPACK_ALLOC;
 
 	msb = n->msi;
 	lsb = n->lsi;
@@ -1980,7 +1980,7 @@ if(!n->extvals)
 	else
 	{
 	char *namex;
-	int was_packed = 0;
+	int was_packed = HIER_DEPACK_ALLOC;
 
 	if(n->lsi > n->msi)
 		{
@@ -2761,6 +2761,11 @@ else if (*w2 == '[')
 		GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = which_ctx];
 		}
       }
+    else if (strcmp (w2, "ruler") == 0)
+      {
+      GLOBALS->ruler_origin = GLOBALS->ruler_step = LLDescriptor(0);
+      sscanf(w, TTFormat" "TTFormat, &GLOBALS->ruler_origin, &GLOBALS->ruler_step);
+      }
     else if (strcmp (w2, "timestart") == 0)
       {
       sscanf(w, TTFormat, &GLOBALS->timestart_from_savefile);
@@ -3324,124 +3329,3 @@ return(made);
 /* LX2 variants */
 /****************/
 
-/*
- * $Id: bitvec.c,v 1.30 2011/01/22 01:29:24 gtkwave Exp $
- * $Log: bitvec.c,v $
- * Revision 1.30  2011/01/22 01:29:24  gtkwave
- * sourcecode cleanup / warnings fixes
- *
- * Revision 1.29  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.28  2010/10/02 18:58:55  gtkwave
- * ctype.h compiler warning fixes (char vs int)
- *
- * Revision 1.27  2010/07/31 20:38:38  gtkwave
- * fix for canonical bit ordering with previous patch
- *
- * Revision 1.26  2010/07/31 20:00:33  gtkwave
- * fix for cvc versus modelsim with respect to created bluespec .sav files
- *
- * Revision 1.25  2010/04/04 19:09:57  gtkwave
- * rename name->bvname in struct BitVector for easier grep tracking
- *
- * Revision 1.24  2010/03/31 15:42:47  gtkwave
- * added preliminary transaction filter support
- *
- * Revision 1.23  2010/03/26 16:11:48  gtkwave
- * added missing break statements in bits2vector switch cases
- *
- * Revision 1.22  2010/03/18 17:12:37  gtkwave
- * pedantic warning cleanups
- *
- * Revision 1.21  2010/03/16 21:01:07  gtkwave
- * remove selected member of struct symbol
- *
- * Revision 1.20  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.19  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.18  2009/12/24 20:55:27  gtkwave
- * warnings cleanups
- *
- * Revision 1.17  2009/11/07 16:40:18  gtkwave
- * null pointer fix on symfind
- *
- * Revision 1.16  2009/09/14 03:00:08  gtkwave
- * bluespec code integration
- *
- * Revision 1.15  2009/08/28 20:29:35  gtkwave
- * Fix to attempt_vecmatch_2 when no suffix encountered.
- *
- * Revision 1.14  2009/03/31 18:49:49  gtkwave
- * removal of warnings under cygwin compile
- *
- * Revision 1.13  2009/01/27 07:04:28  gtkwave
- * added extload external process loader capability
- *
- * Revision 1.12  2008/12/25 03:21:57  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.11  2008/12/11 21:08:15  gtkwave
- * allow support for marker names which are strings
- *
- * Revision 1.10  2008/10/02 00:52:24  gtkwave
- * added dnd of external filetypes into viewer
- *
- * Revision 1.9  2008/09/30 00:27:22  gtkwave
- * fixed ExtractNodeSingleBit for vectors which do not have a zero for msb+lsb
- *
- * Revision 1.8  2008/09/26 17:05:09  gtkwave
- * force open tree nodes in ctree on initial .sav file read (didn't happen
- * before as ctree was not built yet)
- *
- * Revision 1.7  2008/08/24 21:55:27  gtkwave
- * update for timestart line in savefiles
- *
- * Revision 1.6  2008/07/18 19:54:56  gtkwave
- * hierpack and vecmatch fixes with removal of extra brackets
- *
- * Revision 1.5  2008/07/18 19:37:00  gtkwave
- * hierpack fix for makename
- *
- * Revision 1.4  2007/09/23 18:33:53  gtkwave
- * warnings cleanups from sun compile
- *
- * Revision 1.3  2007/08/26 21:35:39  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.5  2007/08/21 22:35:38  gtkwave
- * prelim tree state merge
- *
- * Revision 1.1.1.1.2.4  2007/08/07 03:18:54  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.3  2007/08/06 03:50:45  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.2  2007/08/05 02:27:18  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.1  2007/07/28 19:50:39  kermin
- * Merged in the main line
- *
- * Revision 1.2  2007/07/23 23:13:08  gtkwave
- * adds for color tags in filtered trace data
- *
- * Revision 1.1.1.1  2007/05/30 04:28:02  gtkwave
- * Imported sources
- *
- * Revision 1.4  2007/05/28 00:55:05  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.3  2007/04/29 04:13:49  gtkwave
- * changed anon union defined in struct Node to a named one as anon unions
- * are a gcc extension
- *
- * Revision 1.2  2007/04/20 02:08:11  gtkwave
- * initial release
- *
- */
