@@ -668,7 +668,7 @@ if(GLOBALS->entrybox_text_local_hiersearch_c_1)
 	                efix++;
 	                }
 	
-	        DEBUG(printf("Bundle name is: %s\n",entrybox_text_local));
+	        DEBUG(printf("Bundle name is: %s\n",GLOBALS->entrybox_text_local_hiersearch_c_1));
 	        add_vector_range(GLOBALS->entrybox_text_local_hiersearch_c_1,
 	                        fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which,
 	                        fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which,
@@ -989,71 +989,3 @@ void hier_searchbox(char *title, GtkSignalFunc func)
     refresh_hier_tree(GLOBALS->current_tree_hiersearch_c_1);
 }
 
-/*
- * $Id: hiersearch.c,v 1.10 2011/01/17 19:24:21 gtkwave Exp $
- * $Log: hiersearch.c,v $
- * Revision 1.10  2011/01/17 19:24:21  gtkwave
- * tree modifications to support decorated internal hierarchy nodes
- *
- * Revision 1.9  2010/05/27 06:07:24  gtkwave
- * Moved gtk_grab_add() after gtk_widget_show() as newer gtk needs that order.
- *
- * Revision 1.8  2010/03/16 21:01:09  gtkwave
- * remove selected member of struct symbol
- *
- * Revision 1.7  2008/12/18 01:31:30  gtkwave
- * integrated experimental autoscroll code on signal adds
- *
- * Revision 1.6  2008/02/12 23:35:42  gtkwave
- * preparing for 3.1.5 revision bump
- *
- * Revision 1.5  2008/02/08 02:26:36  gtkwave
- * anti-aliased font support add
- *
- * Revision 1.4  2007/09/12 17:26:44  gtkwave
- * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
- *
- * Revision 1.3  2007/09/10 18:08:49  gtkwave
- * tabs selection can swap dynamically based on external window focus
- *
- * Revision 1.2  2007/08/26 21:35:41  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.8  2007/08/23 02:19:49  gtkwave
- * merge GLOBALS state from old hier_search widget into new one
- *
- * Revision 1.1.1.1.2.7  2007/08/18 21:51:57  gtkwave
- * widget destroys and teardown of file formats which use external loaders
- * and are outside of malloc_2/free_2 control
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:54  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:47  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:20  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:39  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:27:30  gtkwave
- * Imported sources
- *
- * Revision 1.4  2007/05/28 00:55:06  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.3  2007/04/29 04:13:49  gtkwave
- * changed anon union defined in struct Node to a named one as anon unions
- * are a gcc extension
- *
- * Revision 1.2  2007/04/20 02:08:13  gtkwave
- * initial release
- *
- */
-
