@@ -273,7 +273,6 @@ VCD_GETOPT
 "  -r, --rcfile=FILE          specify override .rcfile name\n"
 "  -d, --defaultskip          if missing .rcfile, do not use useful defaults\n"
 DUAL_GETOPT
-"  -i, --indirect=FILE        specify indirect facs file name\n"
 "  -l, --logfile=FILE         specify simulation logfile name for time values\n"
 "  -s, --start=TIME           specify start time for LXT2/VZT block skip\n"
 "  -e, --end=TIME             specify end time for LXT2/VZT block skip\n"  
@@ -576,7 +575,11 @@ if(!GLOBALS)
 	GLOBALS->zoombase = old_g->zoombase;
 	GLOBALS->splash_disable = old_g->splash_disable;
 	GLOBALS->use_pango_fonts = old_g->use_pango_fonts;
-	
+
+	GLOBALS->ruler_origin = old_g->ruler_origin;
+	GLOBALS->ruler_step = old_g->ruler_step;
+	GLOBALS->disable_ae2_alias = old_g->disable_ae2_alias;	
+
 	GLOBALS->vlist_spill_to_disk = old_g->vlist_spill_to_disk;
 	GLOBALS->vlist_prepack = old_g->vlist_prepack;
 	GLOBALS->do_dynamic_treefilter = old_g->do_dynamic_treefilter;
@@ -658,7 +661,6 @@ while (1)
                 {"autosavename", 0, 0, 'A'},
                 {"rcfile", 1, 0, 'r'},
                 {"defaultskip", 0, 0, 'd'},
-                {"indirect", 1, 0, 'i'},
                 {"logfile", 1, 0, 'l'},
                 {"start", 1, 0, 's'},
                 {"end", 1, 0, 'e'},
@@ -687,7 +689,7 @@ while (1)
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "zf:Fon:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:", long_options, 
+        c = getopt_long (argc, argv, "zf:Fon:a:Ar:dl:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:", long_options, 
 &option_index);
 
         if (c == -1) break;     /* no more args */
@@ -839,12 +841,6 @@ while (1)
 			strcpy(override_rc, optarg);
 			break;
 
-                case 'i':
-			if(GLOBALS->indirect_fname) free_2(GLOBALS->indirect_fname);
-			GLOBALS->indirect_fname = malloc_2(strlen(optarg)+1);
-			strcpy(GLOBALS->indirect_fname, optarg);
-			break;
-
                 case 's':
 			if(GLOBALS->skip_start) free_2(GLOBALS->skip_start);
 			GLOBALS->skip_start = malloc_2(strlen(optarg)+1);
@@ -1233,12 +1229,16 @@ else if(suffix_check(GLOBALS->loaded_file_name, ".aet") || suffix_check(GLOBALS-
 	strcpy(GLOBALS->aet_name, GLOBALS->loaded_file_name);
 #endif
         GLOBALS->loaded_file_type = AE2_FILE;
-	ae2_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end, GLOBALS->indirect_fname);
+	ae2_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end);
+#ifdef AET2_IS_PRESENT
 	if(!GLOBALS->ae2)
 		{
 		fprintf(stderr, "GTKWAVE | Could not initialize '%s'%s.\n", GLOBALS->loaded_file_name, GLOBALS->vcd_jmp_buf ? "" : ", exiting");
 		vcd_exit(255);
 		}
+#else
+		/* fails in stubbed out ae2_main() */
+#endif
 	}
 else if (suffix_check(GLOBALS->loaded_file_name, ".ghw") || suffix_check(GLOBALS->loaded_file_name, ".ghw.gz") ||
 		suffix_check(GLOBALS->loaded_file_name, ".ghw.bz2"))
@@ -1263,12 +1263,16 @@ else if (strlen(GLOBALS->loaded_file_name)>4)	/* case for .aet? type filenames *
 		strcpy(GLOBALS->aet_name, GLOBALS->loaded_file_name);
 #endif
                 GLOBALS->loaded_file_type = AE2_FILE;
-		ae2_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end, GLOBALS->indirect_fname);
+#ifdef AET2_IS_PRESENT
+		ae2_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end);
 		if(!GLOBALS->ae2)
 			{
 			fprintf(stderr, "GTKWAVE | Could not initialize '%s'%s.\n", GLOBALS->loaded_file_name, GLOBALS->vcd_jmp_buf ? "" : ", exiting");
 			vcd_exit(255);
 			}
+#else
+		/* fails in stubbed out ae2_main() */
+#endif
 		}
 		else
 		{
@@ -1322,7 +1326,7 @@ load_vcd:
 	}
 
 
-if((GLOBALS->loaded_file_type != FST_FILE) || (!GLOBALS->fast_tree_sort))
+if(((GLOBALS->loaded_file_type != FST_FILE) && (GLOBALS->loaded_file_type != AE2_FILE)) || (!GLOBALS->fast_tree_sort))
 	{
 	GLOBALS->do_hier_compress = 0; /* for now, add more file formats in the future */
 	}
@@ -2732,367 +2736,3 @@ void optimize_vcd_file(void) {
 }
 #endif
 
-/*
- * $Id: main.c,v 1.104 2011/01/13 17:20:39 gtkwave Exp $
- * $Log: main.c,v $
- * Revision 1.104  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.103  2010/11/07 16:20:33  gtkwave
- * make fst the default file format for --optimize action in gtkwave
- *
- * Revision 1.102  2010/10/26 17:37:35  gtkwave
- * added initial_signal_window_width rc variable
- *
- * Revision 1.101  2010/10/06 20:15:51  gtkwave
- * preliminary version of RPC mechanism
- *
- * Revision 1.100  2010/09/14 17:11:56  gtkwave
- * added warning for unimplemented flags (for some systems)
- *
- * Revision 1.99  2010/07/12 20:51:42  gtkwave
- * free to non-malloc'd address fix
- *
- * Revision 1.98  2010/03/31 15:42:47  gtkwave
- * added preliminary transaction filter support
- *
- * Revision 1.97  2010/03/15 15:57:28  gtkwave
- * only allocate hash when necessary
- *
- * Revision 1.96  2010/03/15 03:14:53  gtkwave
- * deallocated symbol hash table after no longer needed
- *
- * Revision 1.95  2010/03/11 16:32:38  gtkwave
- * fix to add .lxt2 suffix recognition
- *
- * Revision 1.94  2010/03/10 18:14:13  gtkwave
- * Toggle Trace Hier fix (cache old value for more usability)
- *
- * Revision 1.93  2010/03/09 21:20:00  gtkwave
- * crash fix for using ->next on a struct after free
- *
- * Revision 1.92  2010/01/22 16:51:21  gtkwave
- * fixes to ensure WAVE_NUM_STRACE_WINDOWS is more maintainable
- *
- * Revision 1.91  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.90  2009/12/24 20:55:27  gtkwave
- * warnings cleanups
- *
- * Revision 1.89  2009/12/16 17:41:21  gtkwave
- * code + documentation cleanups for --script
- *
- * Revision 1.88  2009/12/12 06:06:39  gtkwave
- * added error for --wish if no tcl present
- *
- * Revision 1.87  2009/12/12 01:12:57  gtkwave
- * tcl cross-platform fixes
- *
- * Revision 1.86  2009/12/11 23:41:07  gtkwave
- * cygwin fixes for optimized vcd
- *
- * Revision 1.85  2009/11/17 00:14:40  gtkwave
- * removed redundant is_wish check
- *
- * Revision 1.84  2009/11/11 16:30:57  gtkwave
- * changed tcl library ordering, no tk unless --wish
- *
- * Revision 1.83  2009/11/09 20:09:12  gtkwave
- * made --vcd and --wish mutually exclusive
- *
- * Revision 1.82  2009/11/06 04:15:17  gtkwave
- * gtk+-1.2 compile fixes
- *
- * Revision 1.81  2009/11/05 23:11:09  gtkwave
- * added EnsureGroupsMatch()
- *
- * Revision 1.80  2009/10/07 16:59:07  gtkwave
- * move Tcl_CreateInterp to tcl_helper.c to make stubify easier
- *
- * Revision 1.79  2009/09/22 13:51:13  gtkwave
- * warnings fixes
- *
- * Revision 1.78  2009/09/15 06:21:07  gtkwave
- * simpod-style tcl command reintegration
- *
- * Revision 1.77  2009/09/14 03:00:08  gtkwave
- * bluespec code integration
- *
- * Revision 1.76  2009/08/16 04:41:41  gtkwave
- * fix -d flag across reloads and new tab openings
- *
- * Revision 1.75  2009/08/06 20:03:31  gtkwave
- * warnings fixes
- *
- * Revision 1.74  2009/07/03 18:48:33  gtkwave
- * fst read compatibility fixes for mingw
- *
- * Revision 1.73  2009/06/07 08:40:44  gtkwave
- * adding FST support
- *
- * Revision 1.72  2009/04/24 20:00:03  gtkwave
- * rtlbrowse exit kill mods
- *
- * Revision 1.71  2009/04/24 19:47:15  gtkwave
- * multiple rtlbrowse session kill on gtkwave exit with mult tabs active
- *
- * Revision 1.70  2009/04/24 04:24:22  gtkwave
- * reload and cygwin fixes for rtlbrowse
- *
- * Revision 1.69  2009/04/23 21:57:53  gtkwave
- * added mingw support for rtlbrowse
- *
- * Revision 1.68  2009/04/23 19:38:50  gtkwave
- * add mingw support to twinwave
- *
- * Revision 1.67  2009/04/23 04:57:38  gtkwave
- * ported shmidcat and partial vcd loader function to mingw
- *
- * Revision 1.66  2009/04/11 21:57:53  gtkwave
- * changed exit() to vcd_exit() in some instances for tab loader hardening
- *
- * Revision 1.65  2009/04/09 22:17:21  gtkwave
- * install_keypress_handler() fixes
- *
- * Revision 1.64  2009/03/27 05:08:56  gtkwave
- * disable splash screen for now on empty gui due to undetermine conflicts
- *
- * Revision 1.63  2009/03/27 04:58:14  gtkwave
- * enable splash screen during empty gui handling / load dumpfile
- *
- * Revision 1.62  2009/03/27 04:38:05  gtkwave
- * working on ergonomics of drag and drop into an empty gui
- *
- * Revision 1.61  2009/03/27 00:11:01  gtkwave
- * minor change in -h, --help text when gui enabled
- *
- * Revision 1.60  2009/03/26 23:53:22  gtkwave
- * added disable_empty_gui rc variable which reverts to old behavior
- *
- * Revision 1.59  2009/03/26 20:57:41  gtkwave
- * added MISSING_FILE support for bringing up gtkwave without a dumpfile
- *
- * Revision 1.58  2009/03/09 06:23:37  gtkwave
- * cygwin tcl compatibility fix
- *
- * Revision 1.57  2009/03/05 16:17:56  gtkwave
- * added fastload option
- *
- * Revision 1.56  2009/02/23 18:29:50  gtkwave
- * add more information on init failure for mac users
- *
- * Revision 1.55  2009/02/16 17:16:05  gtkwave
- * extload error hardening and recovery
- *
- * Revision 1.54  2009/01/28 20:06:20  gtkwave
- * changed -ignore to a second --
- *
- * Revision 1.53  2009/01/28 16:28:58  gtkwave
- * added -- -ignore passthrough processing for argv list in main.c
- *
- * Revision 1.52  2009/01/27 07:04:31  gtkwave
- * added extload external process loader capability
- *
- * Revision 1.51  2009/01/19 07:13:11  gtkwave
- * examine CYGWIN env var for "server" before printing warning for rtlbrowse
- *
- * Revision 1.50  2009/01/13 23:09:12  gtkwave
- * added copy traces button to toolbar in gtkwave
- *
- * Revision 1.49  2009/01/12 16:01:45  gtkwave
- * fixed OUTPUT_GETOPT for mingw
- *
- * Revision 1.48  2009/01/12 04:17:39  gtkwave
- * added dynamic zoom for end for partial vcd
- *
- * Revision 1.47  2009/01/08 16:58:22  gtkwave
- * added --output command line flag
- *
- * Revision 1.46  2009/01/02 06:24:28  gtkwave
- * bumped copyright to 2009
- *
- * Revision 1.45  2009/01/02 06:12:48  gtkwave
- * needed check for TCL presence for GLOBALS->interp cloning
- *
- * Revision 1.44  2009/01/02 06:11:00  gtkwave
- * needed to clone GLOBALS->interp from one instance to the next in maketabs
- *
- * Revision 1.43  2009/01/02 06:01:51  gtkwave
- * added getArgv for tcl commands
- *
- * Revision 1.42  2008/12/28 03:03:33  gtkwave
- * Added scale_to_time_dimension rc variable and menu options.
- *
- * Revision 1.41  2008/12/25 04:07:29  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.40  2008/12/20 07:44:22  gtkwave
- * experimental support for Tcl repscripts
- *
- * Revision 1.39  2008/11/17 23:08:54  gtkwave
- * make images in toolbars smaller by removing border space
- *
- * Revision 1.38  2008/10/21 04:03:01  gtkwave
- * setlocale disable for mingw on gtk init
- *
- * Revision 1.37  2008/10/13 22:16:52  gtkwave
- * tcl interpreter integration
- *
- * Revision 1.36  2008/10/04 15:15:20  gtkwave
- * gtk1 compatibility fixes
- *
- * Revision 1.35  2008/10/02 00:52:25  gtkwave
- * added dnd of external filetypes into viewer
- *
- * Revision 1.34  2008/10/01 01:31:38  gtkwave
- * more dnd fixes
- *
- * Revision 1.33  2008/09/26 17:05:10  gtkwave
- * force open tree nodes in ctree on initial .sav file read (didn't happen
- * before as ctree was not built yet)
- *
- * Revision 1.32  2008/09/16 00:01:25  gtkwave
- * prelim drag and drop from external apps (now disabled)
- *
- * Revision 1.31  2008/07/20 01:29:36  gtkwave
- * added command line option --comphier
- *
- * Revision 1.30  2008/07/01 18:51:06  gtkwave
- * compiler warning fixes for amd64
- *
- * Revision 1.29  2008/06/11 08:01:50  gtkwave
- * gcc 4.3.x compiler warning fixes
- *
- * Revision 1.28  2008/04/03 16:45:06  gtkwave
- * removed call to time_trunc with marker setting on initialization
- *
- * Revision 1.27  2008/03/20 01:37:44  gtkwave
- * fix for primary marker time on init (should be -- instead of 0 sec if not
- * specified in a save file)
- *
- * Revision 1.26  2008/02/10 18:08:28  gtkwave
- * removal of logfiles static and moved into global structure
- *
- * Revision 1.25  2008/02/10 01:24:00  gtkwave
- * minor cleanups
- *
- * Revision 1.24  2008/01/09 22:25:55  gtkwave
- * added toolbar spacers, increased starting mainwindow x size
- *
- * Revision 1.23  2008/01/09 19:20:52  gtkwave
- * more updating to globals management (expose events cause wrong swap)
- *
- * Revision 1.22  2008/01/09 08:25:41  gtkwave
- * added cut + paste buttons
- *
- * Revision 1.21  2008/01/09 08:07:03  gtkwave
- * removal of explicit menu string names when unnecessary
- *
- * Revision 1.20  2008/01/09 04:09:11  gtkwave
- * fix keyboard focus sighandler when multi-tabs are being used
- *
- * Revision 1.19  2008/01/08 23:03:35  gtkwave
- * added toolbar using use_toolbutton_interface rc variable
- *
- * Revision 1.18  2008/01/05 22:25:46  gtkwave
- * degate busy during treeview dnd as it disrupts focus; dnd cleanups
- *
- * Revision 1.17  2008/01/02 18:54:11  gtkwave
- * cleaned up inconsistent punctuation on --exit option
- *
- * Revision 1.16  2007/12/30 04:27:39  gtkwave
- * added edge buttons to main window
- *
- * Revision 1.15  2007/12/18 17:28:54  gtkwave
- * added --giga command line option to gtkwave
- *
- * Revision 1.14  2007/09/23 18:33:54  gtkwave
- * warnings cleanups from sun compile
- *
- * Revision 1.13  2007/09/17 19:26:46  gtkwave
- * added dead context sweep code (deferred cleanup of multi-tab destroy)
- *
- * Revision 1.12  2007/09/14 14:08:56  gtkwave
- * updating busy handling
- *
- * Revision 1.11  2007/09/12 19:24:45  gtkwave
- * more ctx_swap_watchdog updates
- *
- * Revision 1.10  2007/09/12 17:26:45  gtkwave
- * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
- *
- * Revision 1.9  2007/09/11 19:56:39  gtkwave
- * missing dynamic cast added
- *
- * Revision 1.8  2007/09/11 17:17:32  gtkwave
- * allow tab movement with context_tabposition rc variable
- *
- * Revision 1.7  2007/09/11 04:27:44  gtkwave
- * duplicate disable_mouseover copy on ctx switch
- *
- * Revision 1.6  2007/09/11 04:13:25  gtkwave
- * loader hardening for tabbed loads
- *
- * Revision 1.5  2007/09/11 02:20:21  gtkwave
- * migrate busy cursor to new tabbed context
- *
- * Revision 1.4  2007/09/09 20:10:30  gtkwave
- * preliminary support for tabbed viewing of multiple waveforms
- *
- * Revision 1.3  2007/08/29 23:38:47  gtkwave
- * 3.1.0 RC2 minor compatibility/bugfixes
- *
- * Revision 1.2  2007/08/26 21:35:42  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.14  2007/08/26 19:13:30  gtkwave
- * datatype fix
- *
- * Revision 1.1.1.1.2.13  2007/08/26 19:05:55  gtkwave
- * added reload button in main window
- *
- * Revision 1.1.1.1.2.12  2007/08/23 23:28:48  gtkwave
- * reload fail handling and retries
- *
- * Revision 1.1.1.1.2.11  2007/08/23 03:16:03  gtkwave
- * NO_FILE now set on stdin sourced VCDs
- *
- * Revision 1.1.1.1.2.10  2007/08/23 02:42:51  gtkwave
- * convert c++ style comments to c to aid with compiler compatibility
- *
- * Revision 1.1.1.1.2.9  2007/08/19 23:13:53  kermin
- * -o flag will now target the original file (in theory reloaded), compress it to lxt2, and then reload the new compressed file.
- *
- * Revision 1.1.1.1.2.8  2007/08/15 03:26:01  kermin
- * Reload button does not cause a fault, however, state is still somehow incorrect.
- *
- * Revision 1.1.1.1.2.7  2007/08/07 04:54:59  gtkwave
- * slight modifications to global initialization scheme
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:54  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:47  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:21  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:39  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:27:56  gtkwave
- * Imported sources
- *
- * Revision 1.3  2007/05/28 00:55:06  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.2  2007/04/20 02:08:13  gtkwave
- * initial release
- *
- */
