@@ -215,6 +215,7 @@ WV_MENU_VZDYN,
 WV_MENU_VZDYNE,
 WV_MENU_VFTP,
 WV_MENU_SEP17,
+WV_MENU_RULER,
 WV_MENU_RMRKS,
 WV_MENU_SEP17A,
 WV_MENU_USECOLOR,
@@ -348,159 +349,3 @@ bvptr combine_traces(int direction, Trptr single_trace_only);
 
 #endif
 
-/*
- * $Id: menu.h,v 1.44 2010/10/06 20:15:51 gtkwave Exp $
- * $Log: menu.h,v $
- * Revision 1.44  2010/10/06 20:15:51  gtkwave
- * preliminary version of RPC mechanism
- *
- * Revision 1.43  2010/08/26 18:42:23  gtkwave
- * added support for transaction filters in mingw
- *
- * Revision 1.42  2010/08/26 01:32:01  gtkwave
- * added mingw support for Open New Window menu option
- *
- * Revision 1.41  2010/08/25 22:58:23  gtkwave
- * added process file support for mingw
- *
- * Revision 1.40  2010/07/12 20:51:42  gtkwave
- * free to non-malloc'd address fix
- *
- * Revision 1.39  2010/07/01 23:02:41  gtkwave
- * header file cleanup
- *
- * Revision 1.38  2010/06/29 02:05:14  gtkwave
- * changed quit accelerator
- *
- * Revision 1.37  2010/06/13 20:38:00  gtkwave
- * added strace repeat count
- *
- * Revision 1.36  2010/04/12 23:07:12  gtkwave
- * add ability to make single signals transactions
- *
- * Revision 1.35  2010/03/31 15:42:47  gtkwave
- * added preliminary transaction filter support
- *
- * Revision 1.34  2010/03/24 23:05:10  gtkwave
- * added RealToBits menu option
- *
- * Revision 1.33  2010/02/24 18:06:14  gtkwave
- * removed reduce single bit vectors
- *
- * Revision 1.32  2010/02/24 17:35:35  gtkwave
- * gtk1 compile fixes
- *
- * Revision 1.31  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.30  2010/01/18 20:47:02  gtkwave
- * added named locker marking
- *
- * Revision 1.29  2009/11/25 09:49:28  gtkwave
- * added gray code support
- *
- * Revision 1.28  2009/09/22 13:51:14  gtkwave
- * warnings fixes
- *
- * Revision 1.27  2009/09/14 03:00:08  gtkwave
- * bluespec code integration
- *
- * Revision 1.26  2009/04/23 21:57:53  gtkwave
- * added mingw support for rtlbrowse
- *
- * Revision 1.25  2009/04/10 04:33:58  gtkwave
- * added menu blackouts on empty gui
- *
- * Revision 1.24  2009/01/13 23:09:12  gtkwave
- * added copy traces button to toolbar in gtkwave
- *
- * Revision 1.23  2009/01/12 04:17:39  gtkwave
- * added dynamic zoom for end for partial vcd
- *
- * Revision 1.22  2008/12/28 03:03:34  gtkwave
- * Added scale_to_time_dimension rc variable and menu options.
- *
- * Revision 1.21  2008/12/16 19:28:20  gtkwave
- * more warnings cleanups
- *
- * Revision 1.20  2008/12/05 19:44:08  gtkwave
- * prelim support for timinganalyzer file format export
- *
- * Revision 1.19  2008/12/04 19:21:00  gtkwave
- * added zoom_dynamic option for partial VCD loading
- *
- * Revision 1.18  2008/11/27 19:37:38  gtkwave
- * disable filter process in windows compiles
- *
- * Revision 1.17  2008/11/25 18:07:32  gtkwave
- * added cut copy paste functionality that survives reload and can do
- * multiple pastes on the same cut buffer
- *
- * Revision 1.16  2008/11/24 02:55:10  gtkwave
- * use TCL_INCLUDE_SPEC to fix ubuntu compiles
- *
- * Revision 1.15  2008/11/19 19:08:34  gtkwave
- * add tcl menu option, update file requester name reentrancy code
- *
- * Revision 1.14  2008/10/14 00:53:46  gtkwave
- * enabled tcl scripts to call existing gtkwave style scripted menu functions
- *
- * Revision 1.13  2008/09/24 23:41:23  gtkwave
- * drag from signal window into external process
- *
- * Revision 1.12  2008/03/25 03:22:11  gtkwave
- * expanded zero fill to include also a one fill (for pre-inverted nets)
- *
- * Revision 1.11  2008/03/24 19:34:00  gtkwave
- * added zero range fill feature
- *
- * Revision 1.10  2008/02/12 23:35:42  gtkwave
- * preparing for 3.1.5 revision bump
- *
- * Revision 1.9  2008/01/25 04:10:14  gtkwave
- * added new resizing options to menu
- *
- * Revision 1.8  2008/01/23 02:05:43  gtkwave
- * added interpolated + step mode
- *
- * Revision 1.7  2008/01/12 21:36:44  gtkwave
- * added black and white vs color rendering menu options
- *
- * Revision 1.6  2007/09/23 18:33:55  gtkwave
- * warnings cleanups from sun compile
- *
- * Revision 1.5  2007/09/09 20:10:30  gtkwave
- * preliminary support for tabbed viewing of multiple waveforms
- *
- * Revision 1.4  2007/08/26 21:35:43  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.6  2007/08/25 19:43:45  gtkwave
- * header cleanups
- *
- * Revision 1.1.1.1.2.5  2007/08/23 02:19:49  gtkwave
- * merge GLOBALS state from old hier_search widget into new one
- *
- * Revision 1.1.1.1.2.4  2007/08/15 03:26:01  kermin
- * Reload button does not cause a fault, however, state is still somehow incorrect.
- *
- * Revision 1.1.1.1.2.3  2007/08/05 02:27:21  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
- * Merged in the main line
- *
- * Revision 1.3  2007/07/23 23:13:08  gtkwave
- * adds for color tags in filtered trace data
- *
- * Revision 1.2  2007/06/18 05:05:08  gtkwave
- * noticed non-extern declaraction (detected only by tcc it seems...)
- *
- * Revision 1.1.1.1  2007/05/30 04:27:58  gtkwave
- * Imported sources
- *
- * Revision 1.2  2007/04/20 02:08:13  gtkwave
- * initial release
- *
- */
-
