@@ -173,7 +173,7 @@ GLOBALS->regex_which_search_c_1=(int)((long)which);
 GLOBALS->regex_mutex_search_c_1[GLOBALS->regex_which_search_c_1] = 1; /* mark our choice */
 
   
-DEBUG(printf("picked: %s\n", regex_name[regex_which]));
+DEBUG(printf("picked: %s\n", regex_name[GLOBALS->regex_which_search_c_1]));
 }  
 
 /***************************************************************************/
@@ -199,7 +199,7 @@ if(GLOBALS->entrybox_text_local_search_c_2)
                 efix++;
                 }
 
-	DEBUG(printf("Bundle name is: %s\n",entrybox_text_local));
+	DEBUG(printf("Bundle name is: %s\n",GLOBALS->entrybox_text_local_search_c_2));
 	add_vector_selected(GLOBALS->entrybox_text_local_search_c_2, GLOBALS->selected_rows_search_c_2, GLOBALS->bundle_direction_search_c_2);
 	free_2(GLOBALS->entrybox_text_local_search_c_2);
 	}
@@ -212,7 +212,7 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 static void
 bundle_callback_generic(void)
 {
-DEBUG(printf("Selected_rows: %d\n",selected_rows));
+DEBUG(printf("Selected_rows: %d\n",GLOBALS->selected_rows_search_c_2));
 if(GLOBALS->selected_rows_search_c_2>0)
 	{
 	entrybox_local("Enter Bundle Name",300,"",128,GTK_SIGNAL_FUNC(bundle_cleanup));
@@ -731,7 +731,7 @@ interval = (gfloat)(GLOBALS->numfacs/100.0);
 
 for(i=0;i<GLOBALS->numfacs;i++)
 	{
-	int was_packed;
+	int was_packed = HIER_DEPACK_STATIC;
 	char *hfacname = NULL;
 
 	GLOBALS->pdata->value = i;
@@ -779,12 +779,12 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		GLOBALS->num_rows_search_c_2++;
 		if(GLOBALS->num_rows_search_c_2==WAVE_MAX_CLIST_LENGTH) 
 			{
-			if(was_packed) { free_2(hfacname); }
+			/* if(was_packed) { free_2(hfacname); } ...not needed with HIER_DEPACK_STATIC */
 			break;
 			}
 		}
 
-	if(was_packed) { free_2(hfacname); }
+	/* if(was_packed) { free_2(hfacname); } ...not needed with HIER_DEPACK_STATIC */
 	}
 
 if(depack_cnt) 
@@ -1100,103 +1100,3 @@ void searchbox(char *title, GtkSignalFunc func)
     if(strlen(GLOBALS->searchbox_text_search_c_1)) search_enter_callback(GLOBALS->entry_search_c_3,NULL);
 }
 
-/*
- * $Id: search.c,v 1.18 2011/01/22 01:29:24 gtkwave Exp $
- * $Log: search.c,v $
- * Revision 1.18  2011/01/22 01:29:24  gtkwave
- * sourcecode cleanup / warnings fixes
- *
- * Revision 1.17  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.16  2010/05/27 06:07:24  gtkwave
- * Moved gtk_grab_add() after gtk_widget_show() as newer gtk needs that order.
- *
- * Revision 1.15  2010/03/16 21:01:10  gtkwave
- * remove selected member of struct symbol
- *
- * Revision 1.14  2010/02/18 23:06:04  gtkwave
- * change name of main iteration loop calls
- *
- * Revision 1.13  2008/12/18 01:31:30  gtkwave
- * integrated experimental autoscroll code on signal adds
- *
- * Revision 1.12  2008/09/24 15:37:38  gtkwave
- * move "selected" to top bit on blasted vector selection w/coalesce
- *
- * Revision 1.11  2008/09/24 02:22:49  gtkwave
- * added (commented out) prelim support for dragging names from viewer
- *
- * Revision 1.10  2008/09/16 00:01:26  gtkwave
- * prelim drag and drop from external apps (now disabled)
- *
- * Revision 1.9  2008/07/18 17:27:01  gtkwave
- * adding hierpack code
- *
- * Revision 1.8  2008/06/11 08:01:54  gtkwave
- * gcc 4.3.x compiler warning fixes
- *
- * Revision 1.7  2008/05/08 20:10:04  gtkwave
- * 2.4 not required for dnd so requirement relaxed
- *
- * Revision 1.6  2008/05/05 19:27:05  gtkwave
- * support for DND from regex search window to sig/waveareas
- *
- * Revision 1.5  2007/09/12 17:26:45  gtkwave
- * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
- *
- * Revision 1.4  2007/09/11 02:12:50  gtkwave
- * context locking in busy spinloops (gtk_main_iteration() calls)
- *
- * Revision 1.3  2007/09/10 18:08:49  gtkwave
- * tabs selection can swap dynamically based on external window focus
- *
- * Revision 1.2  2007/08/26 21:35:44  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.11  2007/08/25 19:43:46  gtkwave
- * header cleanups
- *
- * Revision 1.1.1.1.2.10  2007/08/22 22:17:55  gtkwave
- * sizing fix for int<->long<->void* conversion on 64-bit machines
- *
- * Revision 1.1.1.1.2.9  2007/08/22 22:11:05  gtkwave
- * make regex search for signals re-entrant
- *
- * Revision 1.1.1.1.2.8  2007/08/18 21:51:57  gtkwave
- * widget destroys and teardown of file formats which use external loaders
- * and are outside of malloc_2/free_2 control
- *
- * Revision 1.1.1.1.2.7  2007/08/07 04:54:59  gtkwave
- * slight modifications to global initialization scheme
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:48  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:23  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:27:57  gtkwave
- * Imported sources
- *
- * Revision 1.4  2007/05/28 00:55:06  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.3  2007/04/29 04:13:49  gtkwave
- * changed anon union defined in struct Node to a named one as anon unions
- * are a gcc extension
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
