@@ -136,7 +136,7 @@ char *name = NULL;
        }
      else
        {
-	 int flagged = 0;
+	 int flagged = HIER_DEPACK_ALLOC;
 
 	 name = hier_decompress_flagged(t->n.nd->nname, &flagged);
 	 if(!flagged)
@@ -192,7 +192,7 @@ if(objc == 2)
 
 	if((which >= 0) && (which < GLOBALS->numfacs))
 		{
-		int was_packed = 0;
+		int was_packed = HIER_DEPACK_ALLOC;
         	char *hfacname = NULL;
 
         	hfacname = hier_decompress_flagged(GLOBALS->facs[which]->name, &was_packed);
@@ -2105,150 +2105,3 @@ static void dummy_function(void)
 #endif
 
 
-/*
- * $Id: tcl_commands.c,v 1.46 2011/01/13 17:20:39 gtkwave Exp $
- * $Log: tcl_commands.c,v $
- * Revision 1.46  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.45  2010/10/26 17:37:35  gtkwave
- * added initial_signal_window_width rc variable
- *
- * Revision 1.44  2010/08/17 01:51:35  gtkwave
- * added missing global in error message
- *
- * Revision 1.43  2010/08/15 18:54:49  gtkwave
- * fixes to SST open node to support tcl bug workaround (?)
- *
- * Revision 1.42  2010/07/28 19:56:27  gtkwave
- * locking down callbacks from calling context changing events in viewer
- *
- * Revision 1.41  2010/07/19 22:32:31  gtkwave
- * added gtkwave::setCurrentTranslateEnums
- *
- * Revision 1.40  2010/07/19 21:12:19  gtkwave
- * added file/proc/trans access functions to Tcl script interpreter
- *
- * Revision 1.39  2010/05/21 19:47:58  gtkwave
- * fixes to tcl string handling on { ... } string case.
- *
- * Revision 1.38  2010/04/04 19:09:57  gtkwave
- * rename name->bvname in struct BitVector for easier grep tracking
- *
- * Revision 1.37  2010/03/18 17:12:37  gtkwave
- * pedantic warning cleanups
- *
- * Revision 1.36  2010/02/18 23:06:04  gtkwave
- * change name of main iteration loop calls
- *
- * Revision 1.35  2009/12/24 20:55:27  gtkwave
- * warnings cleanups
- *
- * Revision 1.34  2009/11/29 19:16:13  gtkwave
- * added gtkwave::setTabActive and gtkwave::getNumTabs
- *
- * Revision 1.33  2009/11/29 18:38:20  gtkwave
- * added FST to return types for gtkwave::getDumpType
- *
- * Revision 1.32  2009/11/06 04:15:17  gtkwave
- * gtk+-1.2 compile fixes
- *
- * Revision 1.31  2009/10/26 22:44:01  gtkwave
- * output style fixes, remove double init for bluespec
- *
- * Revision 1.30  2009/10/08 17:40:49  gtkwave
- * removed casting on llist_new, use union instead as arg
- *
- * Revision 1.29  2009/10/07 21:13:10  gtkwave
- * 64-bit fixes on signal list generation
- *
- * Revision 1.28  2009/09/29 02:45:19  gtkwave
- * warnings cleanups
- *
- * Revision 1.27  2009/09/28 05:58:05  gtkwave
- * changes to support signal_change_list
- *
- * Revision 1.26  2009/09/20 21:45:50  gtkwave
- * tree force open node handling changed for tcl
- *
- * Revision 1.25  2009/09/14 03:00:08  gtkwave
- * bluespec code integration
- *
- * Revision 1.24  2009/03/26 20:57:42  gtkwave
- * added MISSING_FILE support for bringing up gtkwave without a dumpfile
- *
- * Revision 1.23  2009/02/16 05:24:32  gtkwave
- * added setBaselineMarker command
- *
- * Revision 1.22  2009/02/02 16:10:42  gtkwave
- * added gtkwavetcl_getTraceFlagsFromName
- *
- * Revision 1.21  2009/01/21 19:52:13  gtkwave
- * allow brackets to be optional on signal delete
- *
- * Revision 1.20  2009/01/21 16:23:25  gtkwave
- * fixed delete behavior so it deletes only the 1st instance appropriately
- *
- * Revision 1.19  2009/01/21 02:24:15  gtkwave
- * gtk1 compile fixes, ensure ctree_main is available for force_open_tree_node
- *
- * Revision 1.18  2009/01/20 06:11:48  gtkwave
- * added gtkwave::getDisplayedSignals command
- *
- * Revision 1.17  2009/01/16 19:27:00  gtkwave
- * added more tcl commands
- *
- * Revision 1.16  2009/01/05 03:24:02  gtkwave
- * fixes for calling configure for updated areas
- *
- * Revision 1.15  2009/01/04 21:48:24  gtkwave
- * setNamedMarker fix for a string set followed by a non-string one
- *
- * Revision 1.14  2009/01/02 06:24:28  gtkwave
- * bumped copyright to 2009
- *
- * Revision 1.13  2009/01/02 06:11:00  gtkwave
- * needed to clone GLOBALS->interp from one instance to the next in maketabs
- *
- * Revision 1.12  2009/01/02 06:01:51  gtkwave
- * added getArgv for tcl commands
- *
- * Revision 1.11  2009/01/01 03:55:12  gtkwave
- * more tcl command adds...value retrieval
- *
- * Revision 1.10  2008/12/31 22:20:12  gtkwave
- * adding more tcl commands
- *
- * Revision 1.9  2008/12/25 03:28:55  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.8  2008/12/16 18:21:02  gtkwave
- * can now set named marker user names through Tcl scripts
- *
- * Revision 1.7  2008/11/25 18:07:32  gtkwave
- * added cut copy paste functionality that survives reload and can do
- * multiple pastes on the same cut buffer
- *
- * Revision 1.6  2008/11/24 03:26:52  gtkwave
- * warnings cleanups
- *
- * Revision 1.5  2008/11/24 02:55:10  gtkwave
- * use TCL_INCLUDE_SPEC to fix ubuntu compiles
- *
- * Revision 1.4  2008/11/19 18:15:35  gtkwave
- * add HAVE_LIBTCL to ifdefs which have HAVE_TCL_H
- *
- * Revision 1.3  2008/11/17 16:49:38  gtkwave
- * convert net object to netBus when encountering stranded bits in
- * signal search and tree search window
- *
- * Revision 1.2  2008/10/26 02:36:06  gtkwave
- * added netValue and netBusValue tcl list values from sigwin drag
- *
- * Revision 1.1  2008/10/17 18:05:27  gtkwave
- * split tcl command extensions out into their own separate file
- *
- * Revision 1.1  2008/10/17 18:22:01  gtkwave
- * file creation
- *
- */
