@@ -1020,7 +1020,7 @@ for(ii=0;ii<c;ii++)
 	unesc_len = strlen(unescaped_str);
 	for(i=0;i<GLOBALS->numfacs;i++)
 	        {
-	        int was_packed = 0;
+	        int was_packed = HIER_DEPACK_ALLOC;
 	        char *hfacname = NULL;
 	                                 
        		hfacname = hier_decompress_flagged(GLOBALS->facs[curr_srch_idx]->name, &was_packed);
@@ -1056,7 +1056,7 @@ for(ii=0;ii<c;ii++)
 	wave_regex_compile(entry_suffixed, WAVE_REGEX_DND); 
 	for(i=0;i<GLOBALS->numfacs;i++)
 	        {
-	        int was_packed = 0;
+	        int was_packed = HIER_DEPACK_ALLOC;
 	        char *hfacname = NULL;
 	                                 
        		hfacname = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
@@ -1086,7 +1086,7 @@ for(ii=0;ii<c;ii++)
 		wave_regex_compile(entry_suffixed, WAVE_REGEX_DND); 
 		for(i=0;i<GLOBALS->numfacs;i++)
 		        {
-		        int was_packed = 0;
+		        int was_packed = HIER_DEPACK_ALLOC;
 		        char *hfacname = NULL;
 		                                 
         		hfacname = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
@@ -1314,7 +1314,7 @@ char is_bus = 0;
 if(s)
 	{
 	int len;
-	int was_packed = 0;
+	int was_packed = HIER_DEPACK_ALLOC;
 	char *s2;
 
 	s = hier_decompress_flagged(s, &was_packed);	
@@ -2956,293 +2956,3 @@ return(strdup_2("--script TCL_ERROR : Tcl support not compiled into gtkwave\n"))
 #endif
 
 
-/*
- * $Id: tcl_helper.c,v 1.95 2011/01/17 19:24:21 gtkwave Exp $
- * $Log: tcl_helper.c,v $
- * Revision 1.95  2011/01/17 19:24:21  gtkwave
- * tree modifications to support decorated internal hierarchy nodes
- *
- * Revision 1.94  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.93  2010/10/06 21:12:29  gtkwave
- * fix for rpc_script_execute when tcl disabled
- *
- * Revision 1.92  2010/10/06 20:15:51  gtkwave
- * preliminary version of RPC mechanism
- *
- * Revision 1.91  2010/10/02 18:58:55  gtkwave
- * ctype.h compiler warning fixes (char vs int)
- *
- * Revision 1.90  2010/10/02 18:24:38  gtkwave
- * warning fixes
- *
- * Revision 1.89  2010/08/18 15:21:17  gtkwave
- * compile fix for when Tcl is disabled
- *
- * Revision 1.88  2010/08/02 17:27:04  gtkwave
- * added tclcb variable init sequence
- *
- * Revision 1.86  2010/07/30 04:02:50  gtkwave
- * fix for 0msec Tcl timer
- *
- * Revision 1.85  2010/07/28 19:56:27  gtkwave
- * locking down callbacks from calling context changing events in viewer
- *
- * Revision 1.84  2010/07/27 22:52:16  gtkwave
- * added nonblocking setvar (to be used only for well-known reasons)
- *
- * Revision 1.83  2010/07/27 07:22:46  gtkwave
- * block tcl callbacks from calling menu functions (for now)
- *
- * Revision 1.82  2010/07/27 05:34:22  gtkwave
- * add variable locking to prevent recursive tcl callbacks
- *
- * Revision 1.81  2010/07/27 05:01:45  gtkwave
- * added gtkwavetcl_setvar for Tcl callback framework
- *
- * Revision 1.80  2010/07/26 15:32:44  gtkwave
- * free_2 fix in repscript_times (possible context swap)
- *
- * Revision 1.79  2010/07/15 14:27:05  gtkwave
- * repscript timer fix to print stack trace
- *
- * Revision 1.78  2010/04/07 01:50:45  gtkwave
- * improved name handling for bvname, add $next transaction operation
- *
- * Revision 1.77  2010/04/04 19:09:57  gtkwave
- * rename name->bvname in struct BitVector for easier grep tracking
- *
- * Revision 1.76  2010/04/01 03:10:58  gtkwave
- * time warp fixes
- *
- * Revision 1.75  2010/03/31 20:41:03  gtkwave
- * nbits versus nnbits fix
- *
- * Revision 1.74  2010/03/24 23:05:10  gtkwave
- * added RealToBits menu option
- *
- * Revision 1.73  2010/03/18 17:12:37  gtkwave
- * pedantic warning cleanups
- *
- * Revision 1.72  2010/03/16 21:01:11  gtkwave
- * remove selected member of struct symbol
- *
- * Revision 1.71  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.70  2010/03/11 16:32:38  gtkwave
- * fix to add .lxt2 suffix recognition
- *
- * Revision 1.69  2010/02/18 23:06:04  gtkwave
- * change name of main iteration loop calls
- *
- * Revision 1.68  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.67  2009/12/24 20:55:27  gtkwave
- * warnings cleanups
- *
- * Revision 1.66  2009/12/22 20:02:19  gtkwave
- * fixed usage of NULL for a char assign
- *
- * Revision 1.65  2009/12/16 17:41:21  gtkwave
- * code + documentation cleanups for --script
- *
- * Revision 1.64  2009/12/15 23:40:59  gtkwave
- * removed old style scripts; also removed tempfiles for Tcl args
- *
- * Revision 1.63  2009/12/11 19:48:59  gtkwave
- * mingw tcl fixes
- *
- * Revision 1.62  2009/11/11 16:30:58  gtkwave
- * changed tcl library ordering, no tk unless --wish
- *
- * Revision 1.61  2009/11/05 23:11:09  gtkwave
- * added EnsureGroupsMatch()
- *
- * Revision 1.60  2009/10/26 22:44:01  gtkwave
- * output style fixes, remove double init for bluespec
- *
- * Revision 1.59  2009/10/24 01:51:41  gtkwave
- * added dynamic loading for tcl/tk via --enable-stubify
- *
- * Revision 1.58  2009/10/23 20:10:33  gtkwave
- * compatibility cleanups with syntax
- *
- * Revision 1.57  2009/10/07 16:59:08  gtkwave
- * move Tcl_CreateInterp to tcl_helper.c to make stubify easier
- *
- * Revision 1.56  2009/09/22 13:51:14  gtkwave
- * warnings fixes
- *
- * Revision 1.55  2009/09/15 06:21:07  gtkwave
- * simpod-style tcl command reintegration
- *
- * Revision 1.54  2009/09/14 03:00:08  gtkwave
- * bluespec code integration
- *
- * Revision 1.53  2009/06/08 06:03:47  gtkwave
- * add fst to dnd filetypes
- *
- * Revision 1.52  2009/03/31 18:49:49  gtkwave
- * removal of warnings under cygwin compile
- *
- * Revision 1.51  2009/03/27 04:38:05  gtkwave
- * working on ergonomics of drag and drop into an empty gui
- *
- * Revision 1.50  2009/03/26 23:53:22  gtkwave
- * added disable_empty_gui rc variable which reverts to old behavior
- *
- * Revision 1.49  2009/03/26 20:57:42  gtkwave
- * added MISSING_FILE support for bringing up gtkwave without a dumpfile
- *
- * Revision 1.48  2009/03/24 20:51:53  gtkwave
- * add static to const qualifier for some declarations to avoid stack push
- *
- * Revision 1.47  2009/02/16 20:55:10  gtkwave
- * added extload to dnd filetypes.  set window title on tab close
- *
- * Revision 1.46  2009/01/23 19:23:10  gtkwave
- * compatibility fix for gcc 3.x
- *
- * Revision 1.45  2009/01/20 06:11:48  gtkwave
- * added gtkwave::getDisplayedSignals command
- *
- * Revision 1.44  2009/01/07 18:53:10  gtkwave
- * move when local_script_handle is set...original was incorrect
- *
- * Revision 1.43  2009/01/07 17:29:51  gtkwave
- * keep local version of script handle for executing menu ops
- *
- * Revision 1.42  2009/01/02 06:24:28  gtkwave
- * bumped copyright to 2009
- *
- * Revision 1.41  2009/01/02 06:01:51  gtkwave
- * added getArgv for tcl commands
- *
- * Revision 1.40  2008/12/27 19:55:06  gtkwave
- * remove stray tempfiles under MinGW
- *
- * Revision 1.39  2008/12/25 03:28:55  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.38  2008/12/20 19:42:11  gtkwave
- * add static initializer to timer functions to avoid non-initialized viewer
- * state when first starting (if timer interrupt fires)
- *
- * Revision 1.37  2008/12/20 07:44:22  gtkwave
- * experimental support for Tcl repscripts
- *
- * Revision 1.36  2008/12/16 19:35:22  gtkwave
- * fixed missing bounds checking
- *
- * Revision 1.35  2008/12/16 19:28:20  gtkwave
- * more warnings cleanups
- *
- * Revision 1.34  2008/11/25 18:07:32  gtkwave
- * added cut copy paste functionality that survives reload and can do
- * multiple pastes on the same cut buffer
- *
- * Revision 1.33  2008/11/24 02:55:10  gtkwave
- * use TCL_INCLUDE_SPEC to fix ubuntu compiles
- *
- * Revision 1.32  2008/11/19 18:15:35  gtkwave
- * add HAVE_LIBTCL to ifdefs which have HAVE_TCL_H
- *
- * Revision 1.31  2008/11/17 16:49:38  gtkwave
- * convert net object to netBus when encountering stranded bits in
- * signal search and tree search window
- *
- * Revision 1.30  2008/11/13 19:13:39  gtkwave
- * fixes for bitblasted nets in DnD
- *
- * Revision 1.29  2008/11/08 19:17:51  gtkwave
- * detected coalesced vectors which all contain same prefix and emit the
- * netBus/netBusValue versions accordingly.
- *
- * Revision 1.28  2008/10/26 02:36:06  gtkwave
- * added netValue and netBusValue tcl list values from sigwin drag
- *
- * Revision 1.27  2008/10/23 17:14:55  gtkwave
- * added marker position to tcl list dragged from signal window
- *
- * Revision 1.26  2008/10/21 03:54:42  gtkwave
- * mingw compile fix
- *
- * Revision 1.25  2008/10/17 18:05:27  gtkwave
- * split tcl command extensions out into their own separate file
- *
- * Revision 1.24  2008/10/17 15:32:49  gtkwave
- * beginning to add error messages on malformed commands
- *
- * Revision 1.23  2008/10/17 14:42:35  gtkwave
- * added findNextEdge/findPrevEdge to tcl interpreter
- *
- * Revision 1.22  2008/10/15 19:13:22  gtkwave
- * added addSignalsFromList command
- *
- * Revision 1.21  2008/10/14 22:06:32  gtkwave
- * added scroll get/set for trace row
- *
- * Revision 1.20  2008/10/14 20:47:53  gtkwave
- * more setXX adds for tcl
- *
- * Revision 1.19  2008/10/14 19:39:04  gtkwave
- * beginning to add setXX capability from tcl scripts
- *
- * Revision 1.18  2008/10/14 18:56:12  gtkwave
- * starting to add getXX functions called from tcl
- *
- * Revision 1.17  2008/10/14 03:32:09  gtkwave
- * starting to add non-menu commands
- *
- * Revision 1.16  2008/10/14 00:53:46  gtkwave
- * enabled tcl scripts to call existing gtkwave style scripted menu functions
- *
- * Revision 1.15  2008/10/13 22:16:52  gtkwave
- * tcl interpreter integration
- *
- * Revision 1.14  2008/10/04 21:00:08  gtkwave
- * do direct search before any attempted regex ones in list process
- *
- * Revision 1.13  2008/10/04 15:15:20  gtkwave
- * gtk1 compatibility fixes
- *
- * Revision 1.12  2008/10/02 00:52:25  gtkwave
- * added dnd of external filetypes into viewer
- *
- * Revision 1.11  2008/09/30 06:32:00  gtkwave
- * added dnd support for comment traces, collapse groups, blank traces
- *
- * Revision 1.10  2008/09/29 22:46:39  gtkwave
- * complex dnd handling with gtkwave trace attributes
- *
- * Revision 1.9  2008/09/27 19:08:39  gtkwave
- * compiler warning fixes
- *
- * Revision 1.8  2008/09/27 06:26:35  gtkwave
- * twinwave (XEmbed) fixes for self-dnd in signal window
- *
- * Revision 1.7  2008/09/27 05:05:04  gtkwave
- * removed unnecessary sing_len struct item
- *
- * Revision 1.6  2008/09/25 18:23:47  gtkwave
- * cut over to usage of zMergeTclList for list generation
- *
- * Revision 1.5  2008/09/25 01:41:35  gtkwave
- * drag from tree clist window into external process
- *
- * Revision 1.4  2008/09/24 23:41:24  gtkwave
- * drag from signal window into external process
- *
- * Revision 1.3  2008/09/24 18:54:00  gtkwave
- * drag from search widget into external processes
- *
- * Revision 1.2  2008/09/24 02:17:32  gtkwave
- * fix memory leak on recreated signal names at import end
- *
- * Revision 1.1  2008/09/23 18:22:01  gtkwave
- * file creation
- *
- */
