@@ -381,10 +381,10 @@ char *NpMyDirectoryPath(char *path, int path_max_len) {
     
     if (tcl_Init && dladdr(tcl_Init, &info)) {
       NpLog3("using dladdr '%s' => '%s'\n", libname, info.dli_fname);
-      snprintf(dllName, dllNameSize, info.dli_fname);
+      snprintf(dllName, dllNameSize, "%s", info.dli_fname); /* format arg was missing */
     } else
 #  endif
-      snprintf(dllName, dllNameSize, libname);
+      snprintf(dllName, dllNameSize, "%s", libname); /* format arg was missing */
   }
   return TCL_OK;
 }
@@ -768,43 +768,3 @@ static void dummy_compilation_unit(void)
 
 #endif
 
-/*
- * $Id: tcl_np.c,v 1.12 2010/02/09 16:42:48 gtkwave Exp $
- * $Log: tcl_np.c,v $
- * Revision 1.12  2010/02/09 16:42:48  gtkwave
- * Replaced Tcl_GetStringResult() with Tcl_GetVar() on Tk init fail.
- *
- * Revision 1.11  2009/12/24 20:55:27  gtkwave
- * warnings cleanups
- *
- * Revision 1.10  2009/12/12 01:12:57  gtkwave
- * tcl cross-platform fixes
- *
- * Revision 1.9  2009/12/11 22:09:20  gtkwave
- * printf typo fix in NpLoadLibrary
- *
- * Revision 1.8  2009/12/11 20:36:20  gtkwave
- * compile warning fix
- *
- * Revision 1.7  2009/12/11 19:48:59  gtkwave
- * mingw tcl fixes
- *
- * Revision 1.6  2009/11/30 17:09:35  gtkwave
- * NpLog fix for 3 arguments
- *
- * Revision 1.5  2009/11/11 16:30:58  gtkwave
- * changed tcl library ordering, no tk unless --wish
- *
- * Revision 1.4  2009/10/27 21:40:22  gtkwave
- * warnings cleanups
- *
- * Revision 1.3  2009/10/26 22:44:01  gtkwave
- * output style fixes, remove double init for bluespec
- *
- * Revision 1.2  2009/10/24 01:46:32  gtkwave
- * remove dead code
- *
- * Revision 1.1  2009/10/24 01:45:16  gtkwave
- * initial version
- *
- */
