@@ -782,7 +782,7 @@ if(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3)
 	                efix++;
 	                }
 	 
-	        DEBUG(printf("Bundle name is: %s\n",entrybox_text_local));
+	        DEBUG(printf("Bundle name is: %s\n",GLOBALS->entrybox_text_local_treesearch_gtk2_c_3));
 	        add_vector_range(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3, 
 				fetchlow(sel)->t_which,
 				fetchhigh(sel)->t_which, 
@@ -1226,6 +1226,7 @@ do_tooltips:
     gtk_clist_freeze(clist);
     gtk_clist_clear(clist);
 
+    decorated_module_cleanup();
     maketree(NULL, GLOBALS->treeroot);
     gtk_clist_thaw(clist);
 
@@ -1481,6 +1482,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     gtk_clist_freeze(clist);
     gtk_clist_clear(clist);
 
+    decorated_module_cleanup();
     maketree(NULL, GLOBALS->treeroot);
     gtk_clist_thaw(clist);
 
@@ -2154,219 +2156,3 @@ void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 	}
 }
 
-/*
- * $Id: treesearch_gtk2.c,v 1.52 2011/01/18 00:00:12 gtkwave Exp $
- * $Log: treesearch_gtk2.c,v $
- * Revision 1.52  2011/01/18 00:00:12  gtkwave
- * preliminary tree component support
- *
- * Revision 1.51  2011/01/17 19:24:21  gtkwave
- * tree modifications to support decorated internal hierarchy nodes
- *
- * Revision 1.50  2010/09/27 18:54:31  gtkwave
- * add check for null node in dynamic sst creation
- *
- * Revision 1.49  2010/09/27 18:02:35  gtkwave
- * force open tree node fix for dynamic trees
- *
- * Revision 1.48  2010/09/23 22:04:55  gtkwave
- * added incremental SST build code
- *
- * Revision 1.47  2010/07/29 20:54:29  gtkwave
- * add cbTreeExpand and cbTreeCollapse
- *
- * Revision 1.46  2010/07/28 19:18:26  gtkwave
- * added double-click trapping via gtkwave::cbTreeSigDoubleClick
- *
- * Revision 1.45  2010/07/27 19:25:41  gtkwave
- * initial tcl callback function adds
- *
- * Revision 1.44  2010/05/27 06:07:25  gtkwave
- * Moved gtk_grab_add() after gtk_widget_show() as newer gtk needs that order.
- *
- * Revision 1.43  2010/03/18 17:12:37  gtkwave
- * pedantic warning cleanups
- *
- * Revision 1.42  2010/03/16 21:01:12  gtkwave
- * remove selected member of struct symbol
- *
- * Revision 1.41  2009/09/28 05:58:05  gtkwave
- * changes to support signal_change_list
- *
- * Revision 1.40  2009/09/20 21:45:50  gtkwave
- * tree force open node handling changed for tcl
- *
- * Revision 1.39  2009/07/23 20:00:55  gtkwave
- * added type info to signal window mouseover
- *
- * Revision 1.38  2009/07/06 21:41:36  gtkwave
- * evcd support issues
- *
- * Revision 1.37  2009/06/29 18:16:23  gtkwave
- * adding framework for module type annotation on inner tree nodes
- *
- * Revision 1.36  2009/06/27 23:10:32  gtkwave
- * added display of type info for variables in tree view
- *
- * Revision 1.35  2009/01/21 02:24:15  gtkwave
- * gtk1 compile fixes, ensure ctree_main is available for force_open_tree_node
- *
- * Revision 1.34  2008/12/25 04:07:29  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.33  2008/12/18 01:31:30  gtkwave
- * integrated experimental autoscroll code on signal adds
- *
- * Revision 1.32  2008/12/17 16:22:31  gtkwave
- * removed clearing of dnd timer in tree drag code
- *
- * Revision 1.31  2008/12/16 18:09:49  gtkwave
- * add countdown timer to remove dnd cursor in signalwindow
- *
- * Revision 1.30  2008/12/04 17:22:33  gtkwave
- * fix crash on invalid node for force tree open
- *
- * Revision 1.29  2008/11/25 18:07:32  gtkwave
- * added cut copy paste functionality that survives reload and can do
- * multiple pastes on the same cut buffer
- *
- * Revision 1.28  2008/10/02 00:52:25  gtkwave
- * added dnd of external filetypes into viewer
- *
- * Revision 1.27  2008/10/01 01:31:38  gtkwave
- * more dnd fixes
- *
- * Revision 1.26  2008/09/29 22:46:39  gtkwave
- * complex dnd handling with gtkwave trace attributes
- *
- * Revision 1.25  2008/09/27 19:08:39  gtkwave
- * compiler warning fixes
- *
- * Revision 1.24  2008/09/27 06:26:35  gtkwave
- * twinwave (XEmbed) fixes for self-dnd in signal window
- *
- * Revision 1.23  2008/09/25 01:41:36  gtkwave
- * drag from tree clist window into external process
- *
- * Revision 1.22  2008/09/24 23:41:25  gtkwave
- * drag from signal window into external process
- *
- * Revision 1.21  2008/09/24 18:54:00  gtkwave
- * drag from search widget into external processes
- *
- * Revision 1.20  2008/09/24 02:22:49  gtkwave
- * added (commented out) prelim support for dragging names from viewer
- *
- * Revision 1.19  2008/09/23 18:23:03  gtkwave
- * adding more support for DnD from external apps
- *
- * Revision 1.18  2008/09/22 03:27:03  gtkwave
- * more DND adds
- *
- * Revision 1.17  2008/09/16 00:01:27  gtkwave
- * prelim drag and drop from external apps (now disabled)
- *
- * Revision 1.16  2008/08/18 16:10:54  gtkwave
- * adding sticky click semantics on already selected entries
- *
- * Revision 1.15  2008/05/11 03:05:25  gtkwave
- * add gating flag on dnd data request so moving in/out of search window
- * doesn't cause spurious insert ops into the signal/wavewindow
- *
- * Revision 1.14  2008/05/06 19:37:55  gtkwave
- * DND tweaking for drag status
- *
- * Revision 1.13  2008/05/05 19:27:06  gtkwave
- * support for DND from regex search window to sig/waveareas
- *
- * Revision 1.12  2008/02/12 23:35:42  gtkwave
- * preparing for 3.1.5 revision bump
- *
- * Revision 1.11  2008/01/13 19:16:54  gtkwave
- * add busy on vcd_recoder dnd (not normally activated)
- *
- * Revision 1.10  2008/01/08 04:01:12  gtkwave
- * more accelerator key ergonomic updates
- *
- * Revision 1.9  2008/01/05 22:25:46  gtkwave
- * degate busy during treeview dnd as it disrupts focus; dnd cleanups
- *
- * Revision 1.8  2008/01/03 21:55:45  gtkwave
- * various cleanups
- *
- * Revision 1.7  2008/01/03 05:02:14  gtkwave
- * added dnd into wavewindow for both click modes
- *
- * Revision 1.6  2008/01/03 00:09:17  gtkwave
- * preliminary dnd support for use_standard_clicking mode
- *
- * Revision 1.5  2007/12/29 20:19:33  gtkwave
- * added dynamic string updates for entrybox in pattern search and sst
- *
- * Revision 1.4  2007/09/12 17:26:45  gtkwave
- * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
- *
- * Revision 1.3  2007/09/10 18:08:49  gtkwave
- * tabs selection can swap dynamically based on external window focus
- *
- * Revision 1.2  2007/08/26 21:35:46  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.15  2007/08/26 04:56:10  gtkwave
- * remove unused var in expand/collapse
- *
- * Revision 1.1.1.1.2.14  2007/08/26 04:50:04  gtkwave
- * tree clist freeze to remove visual noise
- *
- * Revision 1.1.1.1.2.13  2007/08/26 04:42:59  gtkwave
- * mangled tree fix
- *
- * Revision 1.1.1.1.2.12  2007/08/25 19:43:46  gtkwave
- * header cleanups
- *
- * Revision 1.1.1.1.2.11  2007/08/22 02:06:39  gtkwave
- * merge in treebox() similar to treeboxframe()
- *
- * Revision 1.1.1.1.2.10  2007/08/21 23:29:17  gtkwave
- * merge in tree select state from old ctx
- *
- * Revision 1.1.1.1.2.9  2007/08/21 22:35:40  gtkwave
- * prelim tree state merge
- *
- * Revision 1.1.1.1.2.8  2007/08/18 21:51:57  gtkwave
- * widget destroys and teardown of file formats which use external loaders
- * and are outside of malloc_2/free_2 control
- *
- * Revision 1.1.1.1.2.7  2007/08/07 04:54:59  gtkwave
- * slight modifications to global initialization scheme
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:50  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:27  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:02  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:27:55  gtkwave
- * Imported sources
- *
- * Revision 1.4  2007/05/28 00:55:06  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.3  2007/04/29 04:13:49  gtkwave
- * changed anon union defined in struct Node to a named one as anon unions
- * are a gcc extension
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
